Zot.Type.Keyword (zot v0.18.0)

Describes a keyword list type.

Works like the map type but takes a keyword list as input and produces a keyword list as output, following the shape's key order. The shape may be given as a map or a keyword list, but it is always stored as a keyword list so that the key order is preserved.

Summary

Functions

mode(type, mode)

shape(type, shape)