zot
v0.17.1
Search documentation of zot
Default
Default
In-browser search
Settings
Zot.Type.Struct
(zot v0.17.1)
Describes a struct type that works like a strict map but converts the result to an Elixir struct.
Summary
Functions
module(type, module)
shape(type, shape)
Functions
module(type, module)
shape(type, shape)